@@ -12,7 +12,7 @@ class DecidirSDK:
             self.payment_type = 'distributed'
             self.seller_site_id = merchant['credentials']['decidir']['site_id']
         else:
-            credentials = merchant['credentials']
+            credentials = merchant['credentials']['decidir']
             self.payment_type = 'single'
         self.url = 'https://developers.decidir.com/api/v2'
         self.private_key = credentials['access_token']
